@@ -4,7 +4,7 @@ package Dist::Zilla::App::Command::stale;
 # ABSTRACT: print your distribution's prerequisites and plugins that are out of date
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.047';
+our $VERSION = '0.048';
 
 use Dist::Zilla::App -command;
 
@@ -59,7 +59,8 @@ sub stale_modules
 
     return if not @modules;
 
-    my ($stale_modules, undef) = $plugins[0]->stale_modules(_uniq(@modules));
+    require List::Util; List::Util->VERSION(1.45);
+    my ($stale_modules, undef) = $plugins[0]->stale_modules(List::Util::uniq(@modules));
     return @$stale_modules;
 }
 
@@ -105,7 +106,7 @@ sub execute
         push @authordeps, $self->_missing_authordeps;
 
         $self->app->chrome->logger->unmute;
-        $self->log(join("\n", sort(_uniq(@authordeps))));
+        $self->log(join("\n", sort(List::Util::uniq(@authordeps))));
 
         if (@authordeps)
         {
@@ -151,9 +152,6 @@ sub _missing_authordeps
         };
 }
 
-# until List::Util::uniq exists...
-sub _uniq { keys %{ +{ map { $_ => undef } @_ } } }
-
 1;
 
 __END__
@@ -168,7 +166,7 @@ Dist::Zilla::App::Command::stale - print your distribution's prerequisites and p
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 SYNOPSIS
 
@@ -224,10 +222,10 @@ Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Di
 (or L<bug-Dist-Zilla-Plugin-PromptIfStale@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-PromptIfStale@rt.cpan.org>).
 
 There is also a mailing list available for users of this distribution, at
-http://dzil.org/#mailing-list.
+L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-irc://irc.perl.org/#distzilla.
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
