@@ -4,7 +4,7 @@ package Dist::Zilla::Plugin::EnsureNotStale;
 # ABSTRACT: Abort at build/release time if modules are out of date
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.047';
+our $VERSION = '0.048';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::PromptIfStale';
@@ -29,7 +29,7 @@ Dist::Zilla::Plugin::EnsureNotStale - Abort at build/release time if modules are
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 SYNOPSIS
 
@@ -77,10 +77,10 @@ Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Di
 (or L<bug-Dist-Zilla-Plugin-PromptIfStale@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-PromptIfStale@rt.cpan.org>).
 
 There is also a mailing list available for users of this distribution, at
-http://dzil.org/#mailing-list.
+L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-irc://irc.perl.org/#distzilla.
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
