@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.046-7-g4665148
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.047-10-g939f134
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.047';
+our $VERSION = '0.048';
 
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
@@ -13,7 +13,7 @@ with 'Dist::Zilla::Role::BeforeBuild',
     'Dist::Zilla::Role::BeforeRelease';
 
 use Moose::Util::TypeConstraints 'enum';
-use List::Util 1.33 qw(none any);
+use List::Util 1.45 qw(none any uniq);
 use version;
 use Moose::Util 'find_meta';
 use Path::Tiny;
@@ -23,9 +23,8 @@ use HTTP::Tiny;
 use YAML::Tiny;
 use Module::Path 0.18 'module_path';
 use Module::Metadata 1.000023;
-use Module::CoreList 5.20150214;
 use Encode ();
-use namespace::autoclean -also => ['_uniq'];
+use namespace::autoclean;
 
 sub mvp_multivalue_args { qw(modules skip) }
 sub mvp_aliases { {
@@ -95,9 +94,6 @@ around dump_config => sub
     return $config;
 };
 
-# until List::Util::uniq exists...
-sub _uniq { keys %{ +{ map { $_ => undef } @_ } } }
-
 sub before_build
 {
     my $self = shift;
@@ -110,7 +106,7 @@ sub before_build
             ( $self->check_all_plugins ? $self->_modules_plugin : () ),
         );
 
-        $self->_check_modules(sort(_uniq(@modules))) if @modules;
+        $self->_check_modules(sort(uniq(@modules))) if @modules;
     }
 }
 
@@ -121,7 +117,7 @@ sub after_build
     if ($self->phase eq 'build' and $self->check_all_prereqs)
     {
         my @modules = $self->_modules_prereq;
-        $self->_check_modules(sort(_uniq(@modules))) if @modules;
+        $self->_check_modules(sort(uniq(@modules))) if @modules;
     }
 }
 
@@ -137,7 +133,7 @@ sub before_release
         );
         push @modules, $self->_modules_prereq if $self->check_all_prereqs;
 
-        $self->_check_modules(sort(_uniq(@modules))) if @modules;
+        $self->_check_modules(sort(uniq(@modules))) if @modules;
     }
 }
 
@@ -154,11 +150,14 @@ sub stale_modules
 {
     my ($self, @modules) = @_;
 
+    require Module::CoreList;
+    Module::CoreList->VERSION('5.20151213');
+
     my $cwd = getcwd();
     my $cwd_volume = path($cwd)->volume;
 
     my (@stale_modules, @errors);
-    foreach my $module (sort(_uniq(@modules)))
+    foreach my $module (sort(uniq(@modules)))
     {
         $already_checked{$module}++ if $module eq 'perl';
         next if $already_checked{$module};
@@ -284,7 +283,7 @@ has _authordeps => (
         my @skip = $self->skip;
         [
             grep { my $module = $_; none { $module eq $_ } @skip }
-            _uniq(
+            uniq(
                 map { (%$_)[0] }
                     @{ Dist::Zilla::Util::AuthorDeps::extract_author_deps('.') }
             )
@@ -302,7 +301,7 @@ has _modules_plugin => (
         my @skip = $self->skip;
         [
             grep { my $module = $_; none { $module eq $_ } @skip }
-            _uniq(
+            uniq(
                 map { find_meta($_)->name } @{ $self->zilla->plugins }
             )
         ];
@@ -462,7 +461,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 SYNOPSIS
 
@@ -586,10 +585,10 @@ Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Di
 (or L<bug-Dist-Zilla-Plugin-PromptIfStale@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-PromptIfStale@rt.cpan.org>).
 
 There is also a mailing list available for users of this distribution, at
-http://dzil.org/#mailing-list.
+L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-irc://irc.perl.org/#distzilla.
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
@@ -597,12 +596,22 @@ I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords David Golden
+=for stopwords David Golden Olivier Mengué
+
+=over 4
+
+=item *
 
 David Golden <dagolden@cpan.org>
 
+=item *
+
+Olivier Mengué <dolmen@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2013 by Karen Etheridge.
